Module: Kernel
- Defined in:
- lib/versus/core_ext/kernel.rb
Instance Method Summary collapse
-
#Version(version) ⇒ Object
private
If an arbitrary object need to be converted to a
Version::Number, this is a good way to do it.
Instance Method Details
#Version(version) ⇒ Object (private)
If an arbitrary object need to be converted to a Version::Number, this is
a good way to do it.
The capitalize method follows the Ruby conventions of Array() and String(),
etc. Though in this case Version() actually creates a Version::Number object,
that is far an away the typical use case for the Version module.
14 15 16 |
# File 'lib/versus/core_ext/kernel.rb', line 14 def Version(version) Version::Number.parse(version) end |